#include <Arduino.h>
#include <Wire.h>

//////////////////////////////////////////////
//        RemoteXY include library         //
////////////////////////////////////////////// 

#define REMOTEXY_MODE__SOFTSERIAL
#include <SoftwareSerial.h>

#include <RemoteXY.h>

// RemoteXY connection settings 
#define REMOTEXY_SERIAL_RX 2
#define REMOTEXY_SERIAL_TX 3
#define REMOTEXY_SERIAL_SPEED 9600


// RemoteXY configurate  
#pragma pack(push, 1)
uint8_t RemoteXY_CONF[] =
{ 255,4,0,0,0,43,0,10,13,0,
1,0,43,11,12,12,2,31,87,0,
1,0,43,27,12,12,2,31,83,0,
1,0,23,27,12,12,2,31,65,0,
1,0,63,27,12,12,2,31,68,0 };

// this structure defines all the variables and events of your control interface 
struct {

// input variables
uint8_t W; // =1 if button pressed, else =0 
uint8_t S; // =1 if button pressed, else =0 
uint8_t A; // =1 if button pressed, else =0 
uint8_t D; // =1 if button pressed, else =0 

// other variable
uint8_t connect_flag;  // =1 if wire connected, else =0 

} RemoteXY;
#pragma pack(pop) 

/////////////////////////////////////////////
//           END RemoteXY include         //
///////////////////////////////////////////// 

void Motors_Forward ()
{
  Left_Motor_Forward();
  Right_Motor_Forward();
}

void Motors_Backward ()
{
  Left_Motor_Backward();
  Right_Motor_Backward();
}

void Left_Motor_Forward ()
{
  analogWrite(5,200);
  digitalWrite(6,1);
  digitalWrite(7,0);
}

void Left_Motor_Backward ()
{
  analogWrite(5,200);
  digitalWrite(6,0);
  digitalWrite(7,1);
}

void Left_motor_OFF ()
{
  analogWrite(5,0);
  digitalWrite(6,0);
  digitalWrite(7,0);
}

void Right_Motor_Forward ()
{
  analogWrite(11,200);
  digitalWrite(12,1);
  digitalWrite(13,0);
}

void Right_Motor_Backward ()
{
  analogWrite(11,200);
  digitalWrite(12,0);
  digitalWrite(13,1);
}

void Right_Motor_OFF ()
{
  analogWrite(11,0);
  digitalWrite(12,0);
  digitalWrite(13,0);
}

void Motors_OFF ()
{
  Left_motor_OFF();
  Right_Motor_OFF();
}

void turn_left ()
{
  Right_Motor_Forward();
  Left_motor_OFF();
}

void turn_right ()
{
  Left_Motor_Forward();
  Right_Motor_OFF();
}

void _delay(float seconds)
{
  long endTime = millis() + seconds * 1000;
  while(millis() < endTime) _loop();
}

void setup() 
{
  pinMode(5,OUTPUT);
  pinMode(6,OUTPUT);
  pinMode(7,OUTPUT);
  pinMode(11,OUTPUT);
  pinMode(12,OUTPUT);
  pinMode(13,OUTPUT);

  RemoteXY_Init();  
}

void _loop() 
{
}

void loop() 
{
  RemoteXY_Handler();

  if(RemoteXY.W) Motors_Forward();
  if(RemoteXY.S) Motors_Backward();
  if(RemoteXY.A) turn_left();
  if(RemoteXY.D) turn_right();

  delay(1);
  Motors_OFF();

  _loop();
}
